@@ -14,7 +14,7 @@ def fs_yml2readme(sfc_prj='R4Econ',
                   sph_prj='C:/Users/fan/R4Econ/',
                   spn_prj_bookdown_yml='_bookdown.yml',
                   spn_prj_readme_toc='README_toc.md',
-                  ls_st_ignore=['index.Rmd']):
+                  ls_st_ignore=['index.Rmd', 'README_appendix.md', 'title.Rmd', 'main.Rmd']):
     """Write to file README detailed TOC for files in bookdown yaml list
 
     Parameters
@@ -40,7 +40,7 @@ def fs_yml2readme(sfc_prj='R4Econ',
 
     ls_st_rmd_files = ob_book_yml['rmd_files']
 
-    sfc_main = '_main.Rmd'
+    sfc_main = 'main.Rmd'
     ctr_chapter = 0
     ctr_section = 0
     ctr_subsection = 0
@@ -62,6 +62,7 @@ def fs_yml2readme(sfc_prj='R4Econ',
             if it_pound == 1:
                 ctr_chapter = ctr_chapter + 1
                 ctr_section = 0
+                ctr_subsection = 0
                 st_text_out = '# ' + str(ctr_chapter) + ' ' + \
                               ob_yml_rmd_main.replace("#", "")
                 if ctr_chapter != 1:
@@ -110,4 +111,5 @@ if __name__ == '__main__':
     #               sph_prj=sph_prj,
     #               spn_prj_bookdown_yml=spn_prj_bookdown_yml,
     #               spn_prj_readme_toc=spn_prj_readme_toc)
-    fs_yml2readme()
+
+    fs_yml2readme(sfc_prj='R4Econ', sph_prj='C:/Users/fan/R4Econ/')
